@@ -225,6 +225,47 @@ func TestArrayFilter(t *testing.T) {
 	)
 }
 
+func TestArrayRange(t *testing.T) {
+	// 1 Arg
+	testExpression(t, mockContext("5"), "{@range {0}}", expressions.MakeArray("0", "1", "2", "3", "4"))
+	testExpression(t, mockContext("0"), "{@range {0}}", expressions.MakeArray())
+	testExpression(t, mockContext("-1"), "{@range {0}}", expressions.MakeArray("<VALUE>"))
+	testExpression(t, mockContext("abc"), "{@range {0}}", expressions.MakeArray("<BAD-TYPE>"))
+
+	// 2 Arg
+	testExpression(t, mockContext("5"), "{@range 1 {0}}", expressions.MakeArray("1", "2", "3", "4"))
+	testExpression(t, mockContext("0"), "{@range 0 {0}}", expressions.MakeArray())
+	testExpression(t, mockContext("-1"), "{@range 0 {0}}", expressions.MakeArray("<VALUE>"))
+	testExpression(t, mockContext("-1"), "{@range -1 2}", expressions.MakeArray("-1", "0", "1"))
+	testExpression(t, mockContext("-1"), "{@range 5 3}", expressions.MakeArray("<VALUE>"))
+	testExpression(t, mockContext("abc"), "{@range 0 {0}}", expressions.MakeArray("<BAD-TYPE>"))
+
+	// 3 Arg
+	testExpression(t, mockContext("5"), "{@range 1 {0} 1}", expressions.MakeArray("1", "2", "3", "4"))
+	testExpression(t, mockContext("0"), "{@range 0 {0} 1}", expressions.MakeArray())
+	testExpression(t, mockContext("-1"), "{@range 0 {0} 1}", expressions.MakeArray("<VALUE>"))
+	testExpression(t, mockContext("-1"), "{@range -1 2 1}", expressions.MakeArray("-1", "0", "1"))
+	testExpression(t, mockContext("-1"), "{@range 5 3 1}", expressions.MakeArray("<VALUE>"))
+	testExpression(t, mockContext("abc"), "{@range 0 {0} 1}", expressions.MakeArray("<BAD-TYPE>"))
+	testExpression(t, mockContext(), "{@range 5 1 -1}", expressions.MakeArray("5", "4", "3", "2"))
+
+	// 4+ arg
+	testExpressionErr(t, mockContext(), "{@range 1 2 3 4}", "<ARGN>", ErrArgCount)
+
+	// Other error states
+	testExpression(t, mockContext(), "{@range a}", "<BAD-TYPE>")
+	testExpression(t, mockContext(), "{@range b 5}", "<BAD-TYPE>")
+	testExpression(t, mockContext(), "{@range 0 5 c}", "<BAD-TYPE>")
+	testExpression(t, mockContext(), "{@range 0 5 -1}", "<VALUE>")
+	testExpression(t, mockContext(), "{@range 5 0 2}", "<VALUE>")
+	testExpression(t, mockContext(), "{@range 0 5 0}", "<VALUE>")
+}
+
+func TestArrayFor(t *testing.T) {
+	testExpressionErr(t, mockContext(), "{@for 5}", "<ARGN>", ErrArgCount)
+	testExpression(t, mockContext(), "{@for 2 {lt {1} 5} {sumi {0} 2}}", expressions.MakeArray("2", "4", "6", "8", "10"))
+}
+
 func TestArrayIn(t *testing.T) {
 	testExpression(t, mockContext("ab"), "{@in {0} {$ cd ab qef}}", "1")
 	testExpression(t, mockContext("a"), "{@in {0} {$ cd ab qef}}", "")
